pub struct MetaClientModule {
pub(crate) module_api: DynModuleApi,
pub(crate) admin_auth: Option<ApiAuth>,
}Fields
module_api: DynModuleApiadmin_auth: Option<ApiAuth>Implementations
Sourceimpl MetaClientModule
impl MetaClientModule
Sourcepub(crate) fn admin_auth(&self) -> Result<ApiAuth, MetaAdminError>
pub(crate) fn admin_auth(&self) -> Result<ApiAuth, MetaAdminError>
The admin credentials this client was built with.
Errors
Fails with MetaAdminError::AdminAuthMissing if the client was built
without them.
Sourcepub async fn submit(
&self,
key: MetaKey,
value: MetaValue,
) -> Result<(), MetaAdminError>
pub async fn submit( &self, key: MetaKey, value: MetaValue, ) -> Result<(), MetaAdminError>
Submit a meta consensus value
When threshold amount of peers submits the exact same value it becomes a new consensus value.
To “cancel” previous vote, peer can submit a value equal to the current consensus value.
Errors
Fails with MetaAdminError::AdminAuthMissing if this client holds no
admin credentials, and with MetaAdminError::Federation if the
guardians could not be asked to record the vote.
Sourcepub async fn get_consensus_value(
&self,
key: MetaKey,
) -> Result<Option<MetaConsensusValue>, FederationError>
pub async fn get_consensus_value( &self, key: MetaKey, ) -> Result<Option<MetaConsensusValue>, FederationError>
Get the current meta consensus value along with it’s revision
See Self::get_consensus_value_rev to use when checking for updates.
Errors
Fails with a FederationError if the federation could not be asked
for the value.
Sourcepub async fn get_consensus_value_rev(
&self,
key: MetaKey,
) -> Result<Option<u64>, FederationError>
pub async fn get_consensus_value_rev( &self, key: MetaKey, ) -> Result<Option<u64>, FederationError>
Get the current meta consensus value revision
Each time a meta consensus value changes, the revision increases, so checking just the revision can save a lot of bandwidth in periodic checks.
Errors
Fails with a FederationError if the federation could not be asked
for the revision.
Sourcepub async fn get_submissions(
&self,
key: MetaKey,
) -> Result<BTreeMap<PeerId, MetaValue>, MetaAdminError>
pub async fn get_submissions( &self, key: MetaKey, ) -> Result<BTreeMap<PeerId, MetaValue>, MetaAdminError>
Get current submissions to change the meta consensus value.
Upon changing the consensus
Errors
Fails with MetaAdminError::AdminAuthMissing if this client holds no
admin credentials, and with MetaAdminError::Federation if the
guardians could not be asked for their submissions.